@@ -1,7 +1,7 @@
 package Acme::CPANModules::NO_COLOR;
 
 our $DATE = '2018-12-22'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $LIST = {
     summary => "Modules that follow the NO_COLOR convention",
@@ -20,6 +20,9 @@ _
         {module=>'Color::ANSI::Util'},
         {module=>'Data::Dump::Color'},
         {module=>'Debug::Print'},
+        {module=>'Log::Any::Adapter::Screen'},
+        {module=>'Log::ger::Output::Screen'},
+        {module=>'Progress::Any::Output::TermProgressBar'},
         {module=>'Term::ANSIColor::Conditional'},
         {module=>'Term::ANSIColor::Patch::Conditional'},
         {module=>'Term::App::Roles'},
@@ -46,7 +49,7 @@ Acme::CPANModules::NO_COLOR - Modules that follow the NO_COLOR convention
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::CPANModules::NO_COLOR (from Perl distribution Acme-CPANModules-NO_COLOR), released on 2018-12-22.
+This document describes version 0.003 of Acme::CPANModules::NO_COLOR (from Perl distribution Acme-CPANModules-NO_COLOR), released on 2018-12-22.
 
 =head1 DESCRIPTION
 
@@ -71,6 +74,12 @@ If you know of other modules that should be listed here, please contact me.
 
 =item * L<Debug::Print>
 
+=item * L<Log::Any::Adapter::Screen>
+
+=item * L<Log::ger::Output::Screen>
+
+=item * L<Progress::Any::Output::TermProgressBar>
+
 =item * L<Term::ANSIColor::Conditional>
 
 =item * L<Term::ANSIColor::Patch::Conditional>
